import { RequestConfigExtend } from '@fly-vue/core';
import { AxiosError, AxiosResponse } from 'axios';
declare type Timestamp = number;
interface HttpCacheConfig {
    /**
     * 昌否启用httpCache
     */
    enabled: boolean;
    /**
     * 在该时间之前的请求，禁用Http Cache
     */
    disabledBefore?: Timestamp;
    /**
     * 需要开启缓存的keys(一般为url)
     */
    keysForCache?: string[];
}
/**
 * 为一些基础的远程数据，提供基于localstorage级别的缓存，同时，具备定时自动刷新能力
 * 使用方式：
 * - 开启缓存：
 * 前提：需全局开启HttpCache支持，在Settings.js中增加{httpCache:{enabled:true}}
 * 1、在request的config中添加{cachable:true},或者{cachable:{cacheKey:'key',cachable:true}}
 * 2、全局配置中增加{httpCache:{keysForCache:["key1","key2"]}}
 * - 禁用缓存：
 * 调用httpCacheService.disableCache():默认2s内所有请求缓存全部禁用
 */
export declare class HttpCacheService {
    private _cache_db;
    private _key_for_request_cache;
    onRequest(requestConfig: RequestConfigExtend): Promise<RequestConfigExtend>;
    onResponse(response: AxiosResponse): void;
    onResponseError(error: AxiosError): Promise<AxiosResponse<any>>;
    /**
     * 清空所有缓存
     */
    clearAll(): void;
    /**
     * 禁用缓存
     * @param duration 禁用缓存的时间，默认2s
     * @returns
     */
    disableCache(duration?: number): HttpCacheConfig;
    /**
     * 更新缓存配置
     */
    updateCacheConfig(cfg: HttpCacheConfig): HttpCacheConfig;
    /**
     * 获取全局缓存配置
     * @returns
     */
    getCacheConfig(): HttpCacheConfig;
    private buildRequestCacheConfig;
    private getDB;
    private isExpired;
    private upsertCache;
    private buildAxiosResponse;
}
export {};
