/**
 * 对导航菜单进行预处理
 * @param {*} item 要处理的导航菜单
 * @param {*} parent 该导航菜单的父级菜单
 */
declare function prepareMenu(item: any, parent?: any): any;
export declare const MenuService: {
    prepareMenu: typeof prepareMenu;
    group: boolean;
    adapters: any[];
    siderMenus(): any[];
    headerMenus(): any[];
    /**
     * 设置菜单显示模式，是否支持group模式
     * @param {boolean}} 菜单是否支持group
     */
    setGroupable(value: any): void;
    /**
     * 添加菜单
     * @param {*} menus 菜单数组
     */
    addMenus(menus: any): void;
    /**
     * 对添加到系统的菜单进行预处理
     * @param {*} menus
     */
    prepareMenus(menus: any): void;
    /**
     * 添加菜单适配器，适配器格式：(menu:MenuItem, parent?:MenuItem)=>void，对每个输入的菜单进行转换
     * @param {*} adapter 适配器
     */
    addAdapter(adapter: any): void;
    /**
     * 添加顶部菜单
     * @param {*} menus 顶部菜单
     */
    addHeaderMenus(menus: any): void;
    /**
     * 清空所有顶部菜单
     */
    removeHeaderMenus(): void;
    /**
     * 清空所有侧边栏菜单
     */
    removeSiderMenus(): void;
    /**
     * 远程菜单服务地址
     */
    defaultMenuServiceUrl(): any;
    /**
     * 根据路径信息，查询匹配的菜单
     * @param {String} fullPath
     * @param {Array} menuList
     */
    findByPath(fullPath: any, to: any, from: any): any;
    findById(id: any): any;
    /**
     * 根据菜单的配置，打开这个菜单
     * @param {Menu} menu
     * @param {*} opt  打开额外选项
     */
    open(menu: any, opt: any): void;
    /**
     * 根据参数构造菜单
     * @param {*} opt 菜单参数
     */
    buildMenu(opt: any): any;
    /**
     * 查询顶部菜单
     */
    findHeader(menuOrHeaderName: any): any;
    /**
     * 获取菜单的所有父级记录Id
     * @param {*} menu 菜单
     */
    getAncestorIds(menu: any): any[];
    loadRemoteMenu(url?: any): Promise<void>;
    /**
     * 动态加载菜单的子菜单，通过菜单项的submenuSource项配置进行加载
     * @param {*}} menu 菜单项
     */
    loadSubMenu(menu: any): void;
    filterSiderMenus(headerName?: string): any[];
    /**
     * 设置当前的Header菜单
     * @param {string} headerName header菜单名称
     */
    setHeaderName(headerName: any): void;
    /**
     * 获取当前已设置的Header的名称
     */
    getHeaderName(): any;
    /**
     * 获取当前已设置的Header菜单
     */
    getHeader(): any;
    onRouteChange(to: any, from: any): any;
};
export {};
